# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_operation new_request send_request
#' @include sfn_service.R
NULL

#' Creates an activity
#'
#' Creates an activity. An activity is a task that you write in any
#' programming language and host on any machine that has access to AWS Step
#' Functions. Activities must poll Step Functions using the
#' `GetActivityTask` API action and respond using `SendTask*` API actions.
#' This function lets Step Functions know the existence of your activity
#' and returns an identifier for use in a state machine and when polling
#' from the activity.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_create_activity(name, tags)
#'
#' @param name &#91;required&#93; The name of the activity to create. This name must be unique for your
#' AWS account and region for 90 days. For more information, see [Limits
#' Related to State Machine
#' Executions](https://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions)
#' in the *AWS Step Functions Developer Guide*.
#' 
#' A name must *not* contain:
#' 
#' -   whitespace
#' 
#' -   brackets `&lt; &gt; \{ \} \\[ \\]`
#' 
#' -   wildcard characters `? *`
#' 
#' -   special characters `` \" # \% \\ ^ | ~ \` $ &amp; , ; : / ``
#' 
#' -   control characters (`U+0000-001F`, `U+007F-009F`)
#' @param tags The list of tags to add to a resource.
#'
#' @section Request syntax:
#' ```
#' svc$create_activity(
#'   name = "string",
#'   tags = list(
#'     list(
#'       key = "string",
#'       value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_create_activity
sfn_create_activity <- function(name, tags = NULL) {
  op <- new_operation(
    name = "CreateActivity",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$create_activity_input(name = name, tags = tags)
  output <- .sfn$create_activity_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$create_activity <- sfn_create_activity

#' Creates a state machine
#'
#' Creates a state machine. A state machine consists of a collection of
#' states that can do work (`Task` states), determine to which states to
#' transition next (`Choice` states), stop an execution with an error
#' (`Fail` states), and so on. State machines are specified using a
#' JSON-based, structured language.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_create_state_machine(name, definition, roleArn, tags)
#'
#' @param name &#91;required&#93; The name of the state machine.
#' 
#' A name must *not* contain:
#' 
#' -   whitespace
#' 
#' -   brackets `&lt; &gt; \{ \} \\[ \\]`
#' 
#' -   wildcard characters `? *`
#' 
#' -   special characters `` \" # \% \\ ^ | ~ \` $ &amp; , ; : / ``
#' 
#' -   control characters (`U+0000-001F`, `U+007F-009F`)
#' @param definition &#91;required&#93; The Amazon States Language definition of the state machine. See [Amazon
#' States
#' Language](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html).
#' @param roleArn &#91;required&#93; The Amazon Resource Name (ARN) of the IAM role to use for this state
#' machine.
#' @param tags Tags to be added when creating a state machine.
#'
#' @section Request syntax:
#' ```
#' svc$create_state_machine(
#'   name = "string",
#'   definition = "string",
#'   roleArn = "string",
#'   tags = list(
#'     list(
#'       key = "string",
#'       value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_create_state_machine
sfn_create_state_machine <- function(name, definition, roleArn, tags = NULL) {
  op <- new_operation(
    name = "CreateStateMachine",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$create_state_machine_input(name = name, definition = definition, roleArn = roleArn, tags = tags)
  output <- .sfn$create_state_machine_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$create_state_machine <- sfn_create_state_machine

#' Deletes an activity
#'
#' Deletes an activity.
#'
#' @usage
#' sfn_delete_activity(activityArn)
#'
#' @param activityArn &#91;required&#93; The Amazon Resource Name (ARN) of the activity to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_activity(
#'   activityArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_delete_activity
sfn_delete_activity <- function(activityArn) {
  op <- new_operation(
    name = "DeleteActivity",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$delete_activity_input(activityArn = activityArn)
  output <- .sfn$delete_activity_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$delete_activity <- sfn_delete_activity

#' Deletes a state machine
#'
#' Deletes a state machine. This is an asynchronous operation: It sets the
#' state machine\'s status to `DELETING` and begins the deletion process.
#' Each state machine execution is deleted the next time it makes a state
#' transition.
#' 
#' The state machine itself is deleted after all executions are completed
#' or deleted.
#'
#' @usage
#' sfn_delete_state_machine(stateMachineArn)
#'
#' @param stateMachineArn &#91;required&#93; The Amazon Resource Name (ARN) of the state machine to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_state_machine(
#'   stateMachineArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_delete_state_machine
sfn_delete_state_machine <- function(stateMachineArn) {
  op <- new_operation(
    name = "DeleteStateMachine",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$delete_state_machine_input(stateMachineArn = stateMachineArn)
  output <- .sfn$delete_state_machine_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$delete_state_machine <- sfn_delete_state_machine

#' Describes an activity
#'
#' Describes an activity.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_describe_activity(activityArn)
#'
#' @param activityArn &#91;required&#93; The Amazon Resource Name (ARN) of the activity to describe.
#'
#' @section Request syntax:
#' ```
#' svc$describe_activity(
#'   activityArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_describe_activity
sfn_describe_activity <- function(activityArn) {
  op <- new_operation(
    name = "DescribeActivity",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$describe_activity_input(activityArn = activityArn)
  output <- .sfn$describe_activity_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$describe_activity <- sfn_describe_activity

#' Describes an execution
#'
#' Describes an execution.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_describe_execution(executionArn)
#'
#' @param executionArn &#91;required&#93; The Amazon Resource Name (ARN) of the execution to describe.
#'
#' @section Request syntax:
#' ```
#' svc$describe_execution(
#'   executionArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_describe_execution
sfn_describe_execution <- function(executionArn) {
  op <- new_operation(
    name = "DescribeExecution",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$describe_execution_input(executionArn = executionArn)
  output <- .sfn$describe_execution_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$describe_execution <- sfn_describe_execution

#' Describes a state machine
#'
#' Describes a state machine.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_describe_state_machine(stateMachineArn)
#'
#' @param stateMachineArn &#91;required&#93; The Amazon Resource Name (ARN) of the state machine to describe.
#'
#' @section Request syntax:
#' ```
#' svc$describe_state_machine(
#'   stateMachineArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_describe_state_machine
sfn_describe_state_machine <- function(stateMachineArn) {
  op <- new_operation(
    name = "DescribeStateMachine",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$describe_state_machine_input(stateMachineArn = stateMachineArn)
  output <- .sfn$describe_state_machine_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$describe_state_machine <- sfn_describe_state_machine

#' Describes the state machine associated with a specific execution
#'
#' Describes the state machine associated with a specific execution.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_describe_state_machine_for_execution(executionArn)
#'
#' @param executionArn &#91;required&#93; The Amazon Resource Name (ARN) of the execution you want state machine
#' information for.
#'
#' @section Request syntax:
#' ```
#' svc$describe_state_machine_for_execution(
#'   executionArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_describe_state_machine_for_execution
sfn_describe_state_machine_for_execution <- function(executionArn) {
  op <- new_operation(
    name = "DescribeStateMachineForExecution",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$describe_state_machine_for_execution_input(executionArn = executionArn)
  output <- .sfn$describe_state_machine_for_execution_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$describe_state_machine_for_execution <- sfn_describe_state_machine_for_execution

#' Used by workers to retrieve a task (with the specified activity ARN)
#' which has been scheduled for execution by a running state machine
#'
#' Used by workers to retrieve a task (with the specified activity ARN)
#' which has been scheduled for execution by a running state machine. This
#' initiates a long poll, where the service holds the HTTP connection open
#' and responds as soon as a task becomes available (i.e. an execution of a
#' task of this type is needed.) The maximum time the service holds on to
#' the request before responding is 60 seconds. If no task is available
#' within 60 seconds, the poll returns a `taskToken` with a null string.
#' 
#' Workers should set their client side socket timeout to at least 65
#' seconds (5 seconds higher than the maximum time the service may hold the
#' poll request).
#' 
#' Polling with `GetActivityTask` can cause latency in some
#' implementations. See [Avoid Latency When Polling for Activity
#' Tasks](https://docs.aws.amazon.com/step-functions/latest/dg/bp-activity-pollers.html)
#' in the Step Functions Developer Guide.
#'
#' @usage
#' sfn_get_activity_task(activityArn, workerName)
#'
#' @param activityArn &#91;required&#93; The Amazon Resource Name (ARN) of the activity to retrieve tasks from
#' (assigned when you create the task using CreateActivity.)
#' @param workerName You can provide an arbitrary name in order to identify the worker that
#' the task is assigned to. This name is used when it is logged in the
#' execution history.
#'
#' @section Request syntax:
#' ```
#' svc$get_activity_task(
#'   activityArn = "string",
#'   workerName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_get_activity_task
sfn_get_activity_task <- function(activityArn, workerName = NULL) {
  op <- new_operation(
    name = "GetActivityTask",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$get_activity_task_input(activityArn = activityArn, workerName = workerName)
  output <- .sfn$get_activity_task_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$get_activity_task <- sfn_get_activity_task

#' Returns the history of the specified execution as a list of events
#'
#' Returns the history of the specified execution as a list of events. By
#' default, the results are returned in ascending order of the `timeStamp`
#' of the events. Use the `reverseOrder` parameter to get the latest events
#' first.
#' 
#' If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#'
#' @usage
#' sfn_get_execution_history(executionArn, maxResults, reverseOrder,
#'   nextToken)
#'
#' @param executionArn &#91;required&#93; The Amazon Resource Name (ARN) of the execution.
#' @param maxResults The maximum number of results that are returned per call. You can use
#' `nextToken` to obtain further pages of results. The default is 100 and
#' the maximum allowed page size is 1000. A value of 0 uses the default.
#' 
#' This is only an upper limit. The actual number of results returned per
#' call might be fewer than the specified maximum.
#' @param reverseOrder Lists events in descending order of their `timeStamp`.
#' @param nextToken If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#'
#' @section Request syntax:
#' ```
#' svc$get_execution_history(
#'   executionArn = "string",
#'   maxResults = 123,
#'   reverseOrder = TRUE|FALSE,
#'   nextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_get_execution_history
sfn_get_execution_history <- function(executionArn, maxResults = NULL, reverseOrder = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "GetExecutionHistory",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$get_execution_history_input(executionArn = executionArn, maxResults = maxResults, reverseOrder = reverseOrder, nextToken = nextToken)
  output <- .sfn$get_execution_history_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$get_execution_history <- sfn_get_execution_history

#' Lists the existing activities
#'
#' Lists the existing activities.
#' 
#' If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_list_activities(maxResults, nextToken)
#'
#' @param maxResults The maximum number of results that are returned per call. You can use
#' `nextToken` to obtain further pages of results. The default is 100 and
#' the maximum allowed page size is 1000. A value of 0 uses the default.
#' 
#' This is only an upper limit. The actual number of results returned per
#' call might be fewer than the specified maximum.
#' @param nextToken If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#'
#' @section Request syntax:
#' ```
#' svc$list_activities(
#'   maxResults = 123,
#'   nextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_list_activities
sfn_list_activities <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListActivities",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$list_activities_input(maxResults = maxResults, nextToken = nextToken)
  output <- .sfn$list_activities_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$list_activities <- sfn_list_activities

#' Lists the executions of a state machine that meet the filtering criteria
#'
#' Lists the executions of a state machine that meet the filtering
#' criteria. Results are sorted by time, with the most recent execution
#' first.
#' 
#' If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_list_executions(stateMachineArn, statusFilter, maxResults,
#'   nextToken)
#'
#' @param stateMachineArn &#91;required&#93; The Amazon Resource Name (ARN) of the state machine whose executions is
#' listed.
#' @param statusFilter If specified, only list the executions whose current execution status
#' matches the given filter.
#' @param maxResults The maximum number of results that are returned per call. You can use
#' `nextToken` to obtain further pages of results. The default is 100 and
#' the maximum allowed page size is 1000. A value of 0 uses the default.
#' 
#' This is only an upper limit. The actual number of results returned per
#' call might be fewer than the specified maximum.
#' @param nextToken If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#'
#' @section Request syntax:
#' ```
#' svc$list_executions(
#'   stateMachineArn = "string",
#'   statusFilter = "RUNNING"|"SUCCEEDED"|"FAILED"|"TIMED_OUT"|"ABORTED",
#'   maxResults = 123,
#'   nextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_list_executions
sfn_list_executions <- function(stateMachineArn, statusFilter = NULL, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListExecutions",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$list_executions_input(stateMachineArn = stateMachineArn, statusFilter = statusFilter, maxResults = maxResults, nextToken = nextToken)
  output <- .sfn$list_executions_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$list_executions <- sfn_list_executions

#' Lists the existing state machines
#'
#' Lists the existing state machines.
#' 
#' If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#' 
#' This operation is eventually consistent. The results are best effort and
#' may not reflect very recent updates and changes.
#'
#' @usage
#' sfn_list_state_machines(maxResults, nextToken)
#'
#' @param maxResults The maximum number of results that are returned per call. You can use
#' `nextToken` to obtain further pages of results. The default is 100 and
#' the maximum allowed page size is 1000. A value of 0 uses the default.
#' 
#' This is only an upper limit. The actual number of results returned per
#' call might be fewer than the specified maximum.
#' @param nextToken If `nextToken` is returned, there are more results available. The value
#' of `nextToken` is a unique pagination token for each page. Make the call
#' again using the returned token to retrieve the next page. Keep all other
#' arguments unchanged. Each pagination token expires after 24 hours. Using
#' an expired pagination token will return an *HTTP 400 InvalidToken*
#' error.
#'
#' @section Request syntax:
#' ```
#' svc$list_state_machines(
#'   maxResults = 123,
#'   nextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_list_state_machines
sfn_list_state_machines <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListStateMachines",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$list_state_machines_input(maxResults = maxResults, nextToken = nextToken)
  output <- .sfn$list_state_machines_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$list_state_machines <- sfn_list_state_machines

#' List tags for a given resource
#'
#' List tags for a given resource.
#'
#' @usage
#' sfn_list_tags_for_resource(resourceArn)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) for the Step Functions state machine or
#' activity.
#'
#' @section Request syntax:
#' ```
#' svc$list_tags_for_resource(
#'   resourceArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_list_tags_for_resource
sfn_list_tags_for_resource <- function(resourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$list_tags_for_resource_input(resourceArn = resourceArn)
  output <- .sfn$list_tags_for_resource_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$list_tags_for_resource <- sfn_list_tags_for_resource

#' Used by workers to report that the task identified by the taskToken
#' failed
#'
#' Used by workers to report that the task identified by the `taskToken`
#' failed.
#'
#' @usage
#' sfn_send_task_failure(taskToken, error, cause)
#'
#' @param taskToken &#91;required&#93; The token that represents this task. Task tokens are generated by the
#' service when the tasks are assigned to a worker (see
#' GetActivityTask::taskToken).
#' @param error The error code of the failure.
#' @param cause A more detailed explanation of the cause of the failure.
#'
#' @section Request syntax:
#' ```
#' svc$send_task_failure(
#'   taskToken = "string",
#'   error = "string",
#'   cause = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_send_task_failure
sfn_send_task_failure <- function(taskToken, error = NULL, cause = NULL) {
  op <- new_operation(
    name = "SendTaskFailure",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$send_task_failure_input(taskToken = taskToken, error = error, cause = cause)
  output <- .sfn$send_task_failure_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$send_task_failure <- sfn_send_task_failure

#' Used by workers to report to the service that the task represented by
#' the specified taskToken is still making progress
#'
#' Used by workers to report to the service that the task represented by
#' the specified `taskToken` is still making progress. This action resets
#' the `Heartbeat` clock. The `Heartbeat` threshold is specified in the
#' state machine\'s Amazon States Language definition. This action does not
#' in itself create an event in the execution history. However, if the task
#' times out, the execution history contains an `ActivityTimedOut` event.
#' 
#' The `Timeout` of a task, defined in the state machine\'s Amazon States
#' Language definition, is its maximum allowed duration, regardless of the
#' number of SendTaskHeartbeat requests received.
#' 
#' This operation is only useful for long-lived tasks to report the
#' liveliness of the task.
#'
#' @usage
#' sfn_send_task_heartbeat(taskToken)
#'
#' @param taskToken &#91;required&#93; The token that represents this task. Task tokens are generated by the
#' service when the tasks are assigned to a worker (see
#' GetActivityTaskOutput\\$taskToken).
#'
#' @section Request syntax:
#' ```
#' svc$send_task_heartbeat(
#'   taskToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_send_task_heartbeat
sfn_send_task_heartbeat <- function(taskToken) {
  op <- new_operation(
    name = "SendTaskHeartbeat",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$send_task_heartbeat_input(taskToken = taskToken)
  output <- .sfn$send_task_heartbeat_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$send_task_heartbeat <- sfn_send_task_heartbeat

#' Used by workers to report that the task identified by the taskToken
#' completed successfully
#'
#' Used by workers to report that the task identified by the `taskToken`
#' completed successfully.
#'
#' @usage
#' sfn_send_task_success(taskToken, output)
#'
#' @param taskToken &#91;required&#93; The token that represents this task. Task tokens are generated by the
#' service when the tasks are assigned to a worker (see
#' GetActivityTaskOutput\\$taskToken).
#' @param output &#91;required&#93; The JSON output of the task.
#'
#' @section Request syntax:
#' ```
#' svc$send_task_success(
#'   taskToken = "string",
#'   output = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_send_task_success
sfn_send_task_success <- function(taskToken, output) {
  op <- new_operation(
    name = "SendTaskSuccess",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$send_task_success_input(taskToken = taskToken, output = output)
  output <- .sfn$send_task_success_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$send_task_success <- sfn_send_task_success

#' Starts a state machine execution
#'
#' Starts a state machine execution.
#' 
#' `StartExecution` is idempotent. If `StartExecution` is called with the
#' same name and input as a running execution, the call will succeed and
#' return the same response as the original request. If the execution is
#' closed or if the input is different, it will return a 400
#' `ExecutionAlreadyExists` error. Names can be reused after 90 days.
#'
#' @usage
#' sfn_start_execution(stateMachineArn, name, input)
#'
#' @param stateMachineArn &#91;required&#93; The Amazon Resource Name (ARN) of the state machine to execute.
#' @param name The name of the execution. This name must be unique for your AWS
#' account, region, and state machine for 90 days. For more information,
#' see [Limits Related to State Machine
#' Executions](https://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions)
#' in the *AWS Step Functions Developer Guide*.
#' 
#' A name must *not* contain:
#' 
#' -   whitespace
#' 
#' -   brackets `&lt; &gt; \{ \} \\[ \\]`
#' 
#' -   wildcard characters `? *`
#' 
#' -   special characters `` \" # \% \\ ^ | ~ \` $ &amp; , ; : / ``
#' 
#' -   control characters (`U+0000-001F`, `U+007F-009F`)
#' @param input The string that contains the JSON input data for the execution, for
#' example:
#' 
#' `"input": "\{\"first_name\" : \"test\"\}"`
#' 
#' If you don\'t include any JSON input data, you still must include the
#' two braces, for example: `"input": "\{\}"`
#'
#' @section Request syntax:
#' ```
#' svc$start_execution(
#'   stateMachineArn = "string",
#'   name = "string",
#'   input = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_start_execution
sfn_start_execution <- function(stateMachineArn, name = NULL, input = NULL) {
  op <- new_operation(
    name = "StartExecution",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$start_execution_input(stateMachineArn = stateMachineArn, name = name, input = input)
  output <- .sfn$start_execution_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$start_execution <- sfn_start_execution

#' Stops an execution
#'
#' Stops an execution.
#'
#' @usage
#' sfn_stop_execution(executionArn, error, cause)
#'
#' @param executionArn &#91;required&#93; The Amazon Resource Name (ARN) of the execution to stop.
#' @param error The error code of the failure.
#' @param cause A more detailed explanation of the cause of the failure.
#'
#' @section Request syntax:
#' ```
#' svc$stop_execution(
#'   executionArn = "string",
#'   error = "string",
#'   cause = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_stop_execution
sfn_stop_execution <- function(executionArn, error = NULL, cause = NULL) {
  op <- new_operation(
    name = "StopExecution",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$stop_execution_input(executionArn = executionArn, error = error, cause = cause)
  output <- .sfn$stop_execution_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$stop_execution <- sfn_stop_execution

#' Add a tag to a Step Functions resource
#'
#' Add a tag to a Step Functions resource.
#'
#' @usage
#' sfn_tag_resource(resourceArn, tags)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) for the Step Functions state machine or
#' activity.
#' @param tags &#91;required&#93; The list of tags to add to a resource.
#' 
#' Tags may only contain unicode letters, digits, whitespace, or these
#' symbols: `_ . : / = + - @`.
#'
#' @section Request syntax:
#' ```
#' svc$tag_resource(
#'   resourceArn = "string",
#'   tags = list(
#'     list(
#'       key = "string",
#'       value = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_tag_resource
sfn_tag_resource <- function(resourceArn, tags) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$tag_resource_input(resourceArn = resourceArn, tags = tags)
  output <- .sfn$tag_resource_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$tag_resource <- sfn_tag_resource

#' Remove a tag from a Step Functions resource
#'
#' Remove a tag from a Step Functions resource
#'
#' @usage
#' sfn_untag_resource(resourceArn, tagKeys)
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) for the Step Functions state machine or
#' activity.
#' @param tagKeys &#91;required&#93; The list of tags to remove from the resource.
#'
#' @section Request syntax:
#' ```
#' svc$untag_resource(
#'   resourceArn = "string",
#'   tagKeys = list(
#'     "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_untag_resource
sfn_untag_resource <- function(resourceArn, tagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$untag_resource_input(resourceArn = resourceArn, tagKeys = tagKeys)
  output <- .sfn$untag_resource_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$untag_resource <- sfn_untag_resource

#' Updates an existing state machine by modifying its definition and/or
#' roleArn
#'
#' Updates an existing state machine by modifying its `definition` and/or
#' `roleArn`. Running executions will continue to use the previous
#' `definition` and `roleArn`. You must include at least one of
#' `definition` or `roleArn` or you will receive a
#' `MissingRequiredParameter` error.
#' 
#' All `StartExecution` calls within a few seconds will use the updated
#' `definition` and `roleArn`. Executions started immediately after calling
#' `UpdateStateMachine` may use the previous state machine `definition` and
#' `roleArn`.
#'
#' @usage
#' sfn_update_state_machine(stateMachineArn, definition, roleArn)
#'
#' @param stateMachineArn &#91;required&#93; The Amazon Resource Name (ARN) of the state machine.
#' @param definition The Amazon States Language definition of the state machine. See [Amazon
#' States
#' Language](https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html).
#' @param roleArn The Amazon Resource Name (ARN) of the IAM role of the state machine.
#'
#' @section Request syntax:
#' ```
#' svc$update_state_machine(
#'   stateMachineArn = "string",
#'   definition = "string",
#'   roleArn = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname sfn_update_state_machine
sfn_update_state_machine <- function(stateMachineArn, definition = NULL, roleArn = NULL) {
  op <- new_operation(
    name = "UpdateStateMachine",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .sfn$update_state_machine_input(stateMachineArn = stateMachineArn, definition = definition, roleArn = roleArn)
  output <- .sfn$update_state_machine_output()
  svc <- .sfn$service()
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.sfn$operations$update_state_machine <- sfn_update_state_machine
